#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# Created by Roberto Preste
from apybiomart.apybiomart import list_marts, list_datasets, \
    list_attributes, list_filters, query, aquery

__author__ = """Roberto Preste"""
__email__ = 'robertopreste@gmail.com'
__version__ = '0.2.6'



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# Created by Roberto Preste
import pytest
from pandas.testing import assert_frame_equal
from apybiomart import list_filters


def test_list_filters_default(df_filters_ensembl_hsapiens_gene):
    """
    Test the available filters returned by list_filters() for the
    default dataset (hsapiens_gene_ensembl).
    """
    expect = (df_filters_ensembl_hsapiens_gene
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_filters()
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_filters_ensembl(df_filters_ensembl_hsapiens_gene):
    """
    Test the available filters returned by list_filters() for the
    hsapiens_gene_ensembl dataset.
    """
    expect = (df_filters_ensembl_hsapiens_gene
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_filters("hsapiens_gene_ensembl")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_filters_mouse(df_filters_mouse_mlpj_gene):
    """
    Test the available filters returned by list_filters() for the
    mlpj_gene_ensembl dataset.
    """
    expect = (df_filters_mouse_mlpj_gene
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_filters("mlpj_gene_ensembl")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_filters_sequence(df_filters_sequence_cdingo_genomic):
    """
    Test the available filters returned by list_filters() for the
    cdingo_genomic_sequence dataset.
    """
    expect = (df_filters_sequence_cdingo_genomic
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_filters("cdingo_genomic_sequence")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_filters_ontology(df_filters_ontology_closure_eco):
    """
    Test the available filters returned by list_filters() for the
    closure_ECO dataset.
    """
    expect = (df_filters_ontology_closure_eco
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_filters("closure_ECO")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_filters_genomic(df_filters_genomic_hsapiens_encode):
    """
    Test the available filters returned by list_filters() for the
    hsapiens_encode dataset.
    """
    expect = (df_filters_genomic_hsapiens_encode
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_filters("hsapiens_encode")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_filters_snp(df_filters_snp_chircus_snp):
    """
    Test the available filters returned by list_filters() for the
    chircus_snp dataset.
    """
    expect = (df_filters_snp_chircus_snp
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_filters("chircus_snp")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_filters_funcgen(df_filters_funcgen_hsapiens_peak):
    """
    Test the available filters returned by list_filters() for the
    hsapiens_peak dataset.
    """
    expect = (df_filters_funcgen_hsapiens_peak
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_filters("hsapiens_peak")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# Created by Roberto Preste
import pytest
from pandas.testing import assert_frame_equal
from apybiomart import list_attributes


def test_list_attributes_default(df_attributes_ensembl_hsapiens_gene):
    """
    Test the available attributes returned by list_attributes() for the
    default dataset (hsapiens_gene_ensembl).
    """
    expect = (df_attributes_ensembl_hsapiens_gene
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_attributes()
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_attributes_ensembl(df_attributes_ensembl_hsapiens_gene):
    """
    Test the available attributes returned by list_attributes() for the
    hsapiens_gene_ensembl dataset.
    """
    expect = (df_attributes_ensembl_hsapiens_gene
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_attributes("hsapiens_gene_ensembl")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_attributes_mouse(df_attributes_mouse_mlpj_gene):
    """
    Test the available attributes returned by list_attributes() for the
    mlpj_gene_ensembl dataset.
    """
    expect = (df_attributes_mouse_mlpj_gene
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_attributes("mlpj_gene_ensembl")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_attributes_sequence(df_attributes_sequence_cdingo_genomic):
    """
    Test the available attributes returned by list_attributes() for the
    cdingo_genomic_sequence dataset.
    """
    expect = (df_attributes_sequence_cdingo_genomic
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_attributes("cdingo_genomic_sequence")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_attributes_ontology(df_attributes_ontology_closure_eco):
    """
    Test the available attributes returned by list_attributes() for the
    closure_ECO dataset.
    """
    expect = (df_attributes_ontology_closure_eco
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_attributes("closure_ECO")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_attributes_genomic(df_attributes_genomic_hsapiens_encode):
    """
    Test the available attributes returned by list_attributes() for the
    hsapiens_encode dataset.
    """
    expect = (df_attributes_genomic_hsapiens_encode
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_attributes("hsapiens_encode")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_attributes_snp(df_attributes_snp_chircus_snp):
    """
    Test the available attributes returned by list_attributes() for the
    chircus_snp dataset.
    """
    expect = (df_attributes_snp_chircus_snp
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_attributes("chircus_snp")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_list_attributes_funcgen(df_attributes_funcgen_hsapiens_peak):
    """
    Test the available attributes returned by list_attributes() for the
    hsapiens_peak dataset.
    """
    expect = (df_attributes_funcgen_hsapiens_peak
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_attributes("hsapiens_peak")
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# Created by Roberto Preste
import pytest
from pandas.testing import assert_frame_equal
from apybiomart import query


def test_query_default(df_query_ensembl_hsapiens_gene_chrom_2):
    """
    Test the query results for the default dataset (hsapiens_gene_ensembl).
    """
    expect = (df_query_ensembl_hsapiens_gene_chrom_2
              # .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (query(attributes=["ensembl_gene_id", "external_gene_name"],
                    filters={"chromosome_name": "2"})
              # .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)


def test_query_ensembl(df_query_ensembl_hsapiens_gene_chrom_2):
    """
    Test the query results for the hsapiens_gene_ensembl dataset.
    """
    expect = (df_query_ensembl_hsapiens_gene_chrom_2
              # .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (query(attributes=["ensembl_gene_id", "external_gene_name"],
                    filters={"chromosome_name": "2"},
                    dataset="hsapiens_gene_ensembl")
              # .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# Created by Roberto Preste
import timeit


setup_async = """import asyncio
from apybiomart import aquery
loop = asyncio.get_event_loop()
tasks = [aquery(attributes=["ensembl_gene_id", "external_gene_name"],
                    filters={"chromosome_name": str(i)},
                    dataset="hsapiens_gene_ensembl") 
         for i in range(3)]
"""

to_time_async = "dfs = loop.run_until_complete(asyncio.gather(*tasks))"

print(timeit.timeit(to_time_async, setup=setup_async, number=1))

setup_sync = """from pybiomart import Dataset
dataset = Dataset(name='hsapiens_gene_ensembl',
                  host='http://www.ensembl.org')
"""

to_time_sync = """dfs = [dataset.query(attributes=['ensembl_gene_id', 'external_gene_name'], 
filters={'chromosome_name': [str(i)]})
for i in range(3)]"""

print(timeit.timeit(to_time_sync, setup=setup_sync, number=1))



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# Created by Roberto Preste
import pytest
from pandas.testing import assert_frame_equal
from apybiomart import list_marts


def test_list_marts(df_marts):
    """
    Test the available marts returned by list_marts().
    """
    expect = (df_marts
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))
    result = (list_marts()
              .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    assert_frame_equal(result, expect)




#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# Created by Roberto Preste
import pytest
import asyncio
from pandas.testing import assert_frame_equal
from apybiomart import aquery


def test_aquery_default(df_query_ensembl_hsapiens_gene_chrom_2):
    """
    Test the async query results for the default dataset
    (hsapiens_gene_ensembl).
    """
    expect = (df_query_ensembl_hsapiens_gene_chrom_2
              # .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    loop = asyncio.get_event_loop()
    result = loop.run_until_complete(
        aquery(attributes=["ensembl_gene_id", "external_gene_name"],
               filters={"chromosome_name": "2"})
    ).reset_index(drop=True)

    assert_frame_equal(result, expect)


def test_aquery_ensembl(df_query_ensembl_hsapiens_gene_chrom_2):
    """
    Test the async query results for the hsapiens_gene_ensembl dataset.
    """
    expect = (df_query_ensembl_hsapiens_gene_chrom_2
              # .sort_values(by="name", axis=0)
              .reset_index(drop=True))

    loop = asyncio.get_event_loop()
    result = loop.run_until_complete(
        aquery(attributes=["ensembl_gene_id", "external_gene_name"],
               filters={"chromosome_name": "2"},
               dataset="hsapiens_gene_ensembl")
    ).reset_index(drop=True)

    assert_frame_equal(result, expect)


def test_aquery_ensembl_multi(df_query_ensembl_hsapiens_gene_chrom_1,
                              df_query_ensembl_hsapiens_gene_chrom_2,
                              df_query_ensembl_hsapiens_gene_chrom_3):
    """
    Test the async query results for multiple queries run in a loop for
    the hsapiens_gene_ensembl dataset.
    """
    expect1 = (df_query_ensembl_hsapiens_gene_chrom_1
               .reset_index(drop=True))
    expect2 = (df_query_ensembl_hsapiens_gene_chrom_2
               .reset_index(drop=True))
    expect3 = (df_query_ensembl_hsapiens_gene_chrom_3
               .reset_index(drop=True))

    loop = asyncio.get_event_loop()
    tasks = [aquery(attributes=["ensembl_gene_id", "external_gene_name"],
                    filters={"chromosome_name": "1"},
                    dataset="hsapiens_gene_ensembl"),
             aquery(attributes=["ensembl_gene_id", "external_gene_name"],
                    filters={"chromosome_name": "2"},
                    dataset="hsapiens_gene_ensembl"),
             aquery(attributes=["ensembl_gene_id", "external_gene_name"],
                    filters={"chromosome_name": "3"},
                    dataset="hsapiens_gene_ensembl")]
    result1, result2, result3 = loop.run_until_complete(asyncio.gather(*tasks))

    assert_frame_equal(result1, expect1)
    assert_frame_equal(result2, expect2)
    assert_frame_equal(result3, expect3)




#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# Created by Roberto Preste
from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ["asyncio==3.4.3", "aiohttp==3.5.4", "pandas==0.24.2"]

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest', ]

setup(  # pragma: no cover
    author="Roberto Preste",
    author_email='robertopreste@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="Async pythonic interface to Biomart. ",
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    long_description_content_type='text/x-rst',
    include_package_data=True,
    keywords='apybiomart',
    name='apybiomart',
    packages=find_packages(include=['apybiomart']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/robertopreste/apybiomart',
    version='0.2.6',
    zip_safe=False,
)
